package com.diagbot.facade;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.diagbot.client.AiptServiceClient;
import com.diagbot.client.bean.Response;
import com.diagbot.dto.RespDTO;
import com.diagbot.dto.SymptomFeatureDTO;
import com.diagbot.entity.QuestionInfo;
import com.diagbot.enums.DisTypeEnum;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.enums.QuestionTypeEnum;
import com.diagbot.exception.CommonErrorCode;
import com.diagbot.exception.CommonException;
import com.diagbot.util.ListUtil;
import com.diagbot.util.RespDTOUtil;
import com.google.common.collect.Lists;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:zhaops
 * @time: 2019/2/26 13:27
 */
@Component
public class FeatureFacade {
    @Autowired
    private AiptServiceClient aiptServiceClient;
    @Autowired
    private QuestionFacade questionFacade;
    @Autowired
    private DisTypeFacade disTypeFacade;

    /**
     * 症状关键词提取
     *
     * @param text
     * @return
     */
    public List<SymptomFeatureDTO> getSymptomFeature(String text) {
        List<SymptomFeatureDTO> symptomFeatureDTOList = Lists.newLinkedList();
        RespDTO<List<Map<String, Object>>> res = aiptServiceClient.symptomFeaturePageData(text);
        if (RespDTOUtil.respIsNG(res)) {
            throw new CommonException(CommonErrorCode.SERVER_IS_ERROR, "AI没有返回结果");
        }
        List<Map<String, Object>> symptomFeatureList = res.data;
        List<String> symptomNameList = Lists.newLinkedList();
        for (Map<String, Object> symptomFeature : symptomFeatureList) {
            if (symptomFeature != null) {
                symptomNameList.add(symptomFeature.get("feature_name").toString());
            }
        }
        if (!ListUtil.isNotEmpty(symptomFeatureList)) {
            throw new CommonException(CommonErrorCode.NOT_EXISTS, "未提取到特征词");
        }
        QueryWrapper<QuestionInfo> questionInfoQueryWrapper = new QueryWrapper<>();
        questionInfoQueryWrapper.eq("is_deleted", IsDeleteEnum.N.getKey()).
                in("tag_name", symptomNameList).
                and(i -> i.eq("type", QuestionTypeEnum.Symptom.getKey()).or().eq("type", QuestionTypeEnum.Disease.getKey())).
                eq("item_type", 0);
        List<QuestionInfo> questionInfoList = questionFacade.list(questionInfoQueryWrapper);
        for (QuestionInfo questionInfo : questionInfoList) {
            SymptomFeatureDTO symptomFeatureDTO = new SymptomFeatureDTO();
            //特征提取出诊断
            if (questionInfo.getType().equals(QuestionTypeEnum.Disease.getKey())) {
                //判断是否有“复诊”关键字
                if (symptomNameList.contains("复诊")) {
                    //判断是否为慢病
                    Boolean isChronic = disTypeFacade.judgeByDisName(questionInfo.getTagName(), DisTypeEnum.CHRONIC.getKey());
                    if (isChronic) {
                        symptomFeatureDTO.setDisType(DisTypeEnum.CHRONIC.getKey());
                    }
                } else {
                    //没有提取到“复诊”这个特征，诊断不处理
                    continue;
                }
            }
            symptomFeatureDTO.setId(questionInfo.getId());
            symptomFeatureDTO.setTagName(questionInfo.getTagName());
            symptomFeatureDTO.setName(questionInfo.getName());
            symptomFeatureDTO.setType(questionInfo.getType());
            symptomFeatureDTOList.add(symptomFeatureDTO);
        }
        return symptomFeatureDTOList;
    }
}