package com.diagbot.facade;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.diagbot.client.AiptServiceClient;
import com.diagbot.client.bean.SearchData;
import com.diagbot.dto.RespDTO;
import com.diagbot.entity.ScaleContent;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.enums.ScaleTypeEnum;
import com.diagbot.exception.CommonErrorCode;
import com.diagbot.exception.CommonException;
import com.diagbot.service.impl.ScaleContentServiceImpl;
import com.diagbot.util.RespDTOUtil;
import com.diagbot.vo.PushVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * @Description: 量表内容
 * @author: zhoutg
 * @time: 2018/11/19 13:19
 */
@Component
public class ScaleContentFacade extends ScaleContentServiceImpl {

    @Autowired
    PushFacade pushFacade;
    @Autowired
    AiptServiceClient aiptServiceClient;

    /**
     * 返回量表内容
     *
     * @return
     */
    public List<ScaleContent> getContent(PushVO pushVO) {
        SearchData searchData = pushFacade.assembleData(pushVO);
        RespDTO<List<ScaleContent>> res = aiptServiceClient.getScale(searchData);
        if (RespDTOUtil.respIsNG(res)) {
            throw new CommonException(CommonErrorCode.RPC_ERROR, "远程调用量表内容失败");
        }
        return res.data;
    }


    /**
     * 返回诊断量表列表
     *
     * @return
     */
    public List<ScaleContent> getContent(Long scaleId, String pushContent) {
        //获取内容列表
        List<ScaleContent> data = this.list(new QueryWrapper<ScaleContent>()
                .eq("scale_id", scaleId)
                .eq("is_deleted", IsDeleteEnum.N.getKey())
                .orderByAsc("order_no"));

        //看需是否要调用大数据
        for (ScaleContent scaleContent : data) {
            if (ScaleTypeEnum.PUSH.getKey() == scaleContent.getType()) {
                scaleContent.setContent(pushContent);
                break;
            }
        }
        return data;
    }
}
